package com.caimei365.user.controller;

import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.ClubRemarksDto;
import com.caimei365.user.model.dto.ClubUpdateDto;
import com.caimei365.user.model.dto.DeductionDto;
import com.caimei365.user.model.dto.JsonParamsDto;
import com.caimei365.user.model.vo.*;
import com.caimei365.user.service.ClubService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.Map;


/**
 * 机构用户API
 *
 * @author : Charles
 * @date : 2021/3/4
 */
@Api(tags = "机构用户API")
@RestController
@RequiredArgsConstructor
@RequestMapping("/user/club")
public class ClubApi {

    private final ClubService clubService;

    /**
     * 根据用户Id查询机构资料
     * <p>
     * spi旧接口：/user/club/applicationData
     *
     * @param userId 用户Id
     * @return Map(userPo, clubPo)
     */
    @ApiOperation("查询机构资料")
    @ApiImplicitParam(required = true, name = "userId", value = "用户Id")
    @GetMapping("/info")
    public ResponseJson<Map<String, Object>> getClubUserInfo(Integer userId) {
        return clubService.getClubUserInfo(userId);
    }

    /**
     * 修改机构资料
     * <p>
     * spi旧接口：/operation/modifiedData
     *
     * @param club ClubUpdateDto:{
     *             clubId                 机构ID
     *             userId                 用户ID
     *             name                   机构名称
     *             shortName                  机构简称(shortName)
     *             contractEmail          邮箱（contractEmail1）
     *             contractPhone          固定电话
     *             linkMan                联系人（linkMan1）
     *             provinceId             省Id
     *             cityId                 市Id
     *             townId                 县区Id
     *             address                地址
     *             shopPhoto              门头照(headpic)
     *             businessLicense        营业执照（businessLicenseImage）
     *             socialCreditCode       统一社会信用代码（socialCreditCode）
     *             firstClubType          一级分类：医美=1和生美=2
     *             secondClubType         医美的二级分类：诊所=1、门诊=2、医院=3。  生美没有二级分类
     *             department             医美分类下的门诊和医院则需要填写科室
     *             medicalPracticeLicense 医美分类必须上传医疗执业许可证（medicalPracticeLicenseImg）
     *             mainProduct            主打项目（mainpro）
     *             fax                    传真
     *             profile                公司简介
     *             }
     * @return ClubUpdateDto
     */
    @ApiOperation("更新机构资料")
    @PostMapping("/info/update")
    public ResponseJson<ClubUpdateDto> updateClubUserInfo(ClubUpdateDto club) {
        return clubService.updateClubUserInfo(club);
    }

    /**
     * 机构个人中心
     * <p>
     * spi旧接口：/personalCenter/myCentre
     *
     * @param userId 用户Id
     * @return Map(userPo, clubPo)
     */
    @ApiOperation("机构个人中心")
    @ApiImplicitParam(required = true, name = "userId", value = "用户Id")
    @GetMapping("/home")
    public ResponseJson<Map<String, Object>> getClubHomeData(Integer userId) {
        return clubService.getClubHomeData(userId);
    }

    /**
     * 赠送采美豆弹窗
     */
    @ApiOperation("赠送采美豆弹窗")
    @ApiImplicitParam(required = true, name = "userId", value = "用户Id")
    @GetMapping("/obtain/beans")
    public ResponseJson<BeansHistoryVo> beansPopUps(Integer userId) {
        if (userId == null) {
            return ResponseJson.error("参数异常", null);
        }
        return clubService.beansPopUps(userId);
    }

    /**
     * 采美豆收支明细
     */
    @ApiOperation("采美豆收支明细")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "userId", value = "用户Id"),
            @ApiImplicitParam(required = true, name = "year", value = "年份"),
            @ApiImplicitParam(required = true, name = "month", value = "月份"),
            @ApiImplicitParam(required = true, name = "type", value = "收支类型：1收入，2支出"),
            @ApiImplicitParam(required = false, name = "pageNum", value = "第几页"),
            @ApiImplicitParam(required = false, name = "pageSize", value = "一页多少条")
    })
    @GetMapping("/beans/history")
    public ResponseJson<Map<String, Object>> beansHistory(Integer userId, Integer year, Integer month, Integer type,
                                                          @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                          @RequestParam(value = "pageSize", defaultValue = "10") int pageSize) {
        if (userId == null || year == null || month == null) {
            return ResponseJson.error("参数异常", null);
        }
        return clubService.beansHistory(userId, year, month, type, pageNum, pageSize);
    }

    @ApiOperation("查看商品资料抵扣采美豆")
    @PostMapping("/archive/deduction")
    public ResponseJson archiveDeduction(DeductionDto deductionDto) {
        Integer userId = deductionDto.getUserId();
        Integer archiveId = deductionDto.getArchiveId();
        if (userId == null || archiveId == null) {
            return ResponseJson.error("参数异常");
        }
        return clubService.archiveDeduction(userId, archiveId);
    }

    @ApiOperation("注册客户咨询记录")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "serviceProviderId", value = "协销Id"),
            @ApiImplicitParam(required = false, name = "keyWord", value = "模糊搜索关键词"),
            @ApiImplicitParam(required = false, name = "startAddTime", value = "添加记录开始时间"),
            @ApiImplicitParam(required = false, name = "endAddTime", value = "添加记录结束时间"),
            @ApiImplicitParam(required = false, name = "consult", value = "咨询类别"),
            @ApiImplicitParam(required = false, name = "leaderId", value = "管理员协销id"),
            @ApiImplicitParam(required = false, name = "groupId", value = "组员协销id"),
            @ApiImplicitParam(required = false, name = "manager", value = "是否是协销总管理员标记 1是，2否"),
            @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
            @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("/remarks/list")
    public ResponseJson<PaginationVo<RemarkVo>> getRemarksList(Integer serviceProviderId,
                                                               String keyWord,
                                                               String startAddTime,
                                                               String endAddTime,
                                                               String consult,
                                                               Integer leaderId,
                                                               Integer groupId,
                                                               Integer manager,
                                                               @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                               @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return clubService.getRemarksList(serviceProviderId, keyWord, startAddTime, endAddTime, consult, leaderId, groupId,manager, pageNum, pageSize);
    }

    @ApiOperation("机构资料备注详情")
    @ApiImplicitParam(required = true, name = "remarksId", value = "机构id")
    @GetMapping("/remarks/detail")
    public ResponseJson<RemarkVo> getRemarksDetail(Integer remarksId) {
        return clubService.getRemarksDetail(remarksId);
    }

    /**
     * @param jsonParamsDto:{ remarksId:           备注id,
     *                        机构id:               机构id,
     *                        questionMan:        咨询人姓名，
     *                        serviceProviderId:   协销id,
     *                        remarks:             文字备注,
     *                        fileList:    [{fileName:"文件名称",ossName:"oss文件名称"},{fileName:"文件名称",ossName:"oss文件名称"}...]
     *                        imageList:   ["图片","图片",...]
     *                        consult: (1,2) 咨询类别id，英文逗号隔开
     *                        }
     */
    @ApiOperation("保存机构资料备注")
    @PostMapping("/remarks/save")
    public ResponseJson saveClubRemarks(JsonParamsDto jsonParamsDto) {
        return clubService.saveClubRemarks(jsonParamsDto);
    }

    @ApiOperation("删除机构资料备注")
    @ApiImplicitParam(required = true, name = "remarksId", value = "机构id")
    @PostMapping("/remarks/delete")
    public ResponseJson deleteClubRemarks(ClubRemarksDto clubRemarksDto) {
        return clubService.deleteClubRemarks(clubRemarksDto.getRemarksId());
    }

    /**
     * 机构个人中心数据
     */
    @ApiOperation("机构个人中心数据(旧：/pcCenter/myPcCenter)")
    @ApiImplicitParam(required = true, name = "userId", value = "用户Id")
    @GetMapping("/personal/data")
    public ResponseJson<Map<String, Object>> getPersonalData(Integer userId) {
        if (null == userId) {
            return ResponseJson.error("参数异常：用户Id不能为空！", null);
        }
        return clubService.getPersonalData(userId);
    }


    /**
     * 添加潜在用户咨询人
     */
    @ApiOperation("添加潜在用户咨询人")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "name", value = "咨询人姓名"),
            @ApiImplicitParam(required = true, name = "serviceProviderId", value = "协销id")
    })
    @GetMapping("/remarks/visitor/save")
    public ResponseJson<Map<String, String>> addVisitorClub(String name, String serviceProviderId) {
        if (null == name || "".equals(name)) {
            return ResponseJson.error("参数异常：咨询人姓名不能为空！", null);
        }
        return clubService.saveVisitorName(name, serviceProviderId);
    }

    /**
     * 潜在用户列表
     */
    @ApiOperation("未注册用户列表")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "serviceProviderId", value = "协销id"),
            @ApiImplicitParam(required = false, name = "keyWord", value = "模糊搜索关键词"),
            @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
            @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("/remarks/visitor/list")
    public ResponseJson<PaginationVo<VisitorRemarkVo>> getVisitorList(Integer serviceProviderId,
//                                                                      String keyWord,
//                                                                      String startAddTime,
//                                                                      String endAddTime,
//                                                                      String consult,
//                                                                      Integer leaderId,
//                                                                      Integer groupId,
//                                                                      Integer manager,
                                                                      @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                      @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        if (null == serviceProviderId) {
            return ResponseJson.error("参数异常：协销id不能为空！", null);
        }
//        keyWord, startAddTime, endAddTime, consult, leaderId, groupId,manager,
        return clubService.getVisitorList(serviceProviderId,  pageNum, pageSize);
    }

    /**
     * 修改潜在用户咨询人姓名
     */
    @ApiOperation("修改潜在用户咨询人姓名")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "serviceProviderId", value = "协销id"),
            @ApiImplicitParam(required = true, name = "questionMan", value = "咨询人姓名"),
            @ApiImplicitParam(required = true, name = "questionManId", value = "咨询人id")
    })
    @GetMapping("/remarks/visitor/update")
    public ResponseJson<String> updateName(String serviceProviderId, String questionMan, String questionManId) {
        if (null == serviceProviderId || "".equals(serviceProviderId)) {
            return ResponseJson.error("参数异常：协销id不能为空！", null);
        }
        if (null == questionMan || "".equals(questionMan)) {
            return ResponseJson.error("参数异常：咨询人不能为空！", null);
        }
        if (null == questionManId || "".equals(questionManId)) {
            return ResponseJson.error("参数异常：咨询人id不能为空！", null);
        }
        return clubService.updateVisitor(serviceProviderId, questionMan, questionManId);
    }

    /**
     * 添加/修改潜在用户记录
     *
     * @param visitor:{ remarksId:              备注id,
     *                  questionManId:               咨询人id,
     *                  serviceProviderId:   协销id,
     *                  remarks:             文字备注,
     *                  fileList:    [{fileName:"文件名称",ossName:"oss文件名称"},{fileName:"文件名称",ossName:"oss文件名称"}...]
     *                  imageList:   ["图片","图片",...]
     *                  consult: (1,2) 咨询类别id，英文逗号隔开
     *                  }
     * @param visitor
     * @return
     */
    @ApiOperation("添加/修改潜在用户记录")
    @PostMapping("/remarks/save/visit")
    public ResponseJson saveVisit(JsonParamsDto visitor) {
        return clubService.saveVisitRecord(visitor);
    }

    @ApiOperation("潜在用户资料备注详情")
    @ApiImplicitParam(required = true, name = "remarksId", value = "资料id")
    @GetMapping("/remarks/detail/visit")
    public ResponseJson<VisitRemarkVo> getVisitRemarksDetail(Integer remarksId) {
        return clubService.getVisitRemark(remarksId);
    }

    /**
     * 潜在用户咨询人记录列表
     */
    @ApiOperation("潜在用户咨询人记录列表")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "questionManId", value = "咨询人id"),
            @ApiImplicitParam(required = false, name = "keyWord", value = "模糊搜索关键词"),
            @ApiImplicitParam(required = false, name = "pageNum", value = "页码"),
            @ApiImplicitParam(required = false, name = "pageSize", value = "每页数量")
    })
    @GetMapping("/remarks/visitor/recordlist")
    public ResponseJson<PaginationVo<VisitRemarkVo>> getVisitorRecordList(String questionManId,
                                                                          String keyWord,
                                                                          Integer serviceProviderId,
                                                                          String startAddTime,
                                                                          String endAddTime,
                                                                          String consult,
                                                                          Integer leaderId,
                                                                          Integer groupId,
                                                                          Integer manager,
                                                                          @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                          @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        if (null == serviceProviderId) {
            return ResponseJson.error("参数异常：协销id不能为空！", null);
        }
        return clubService.getVisitorRecordList(questionManId,keyWord,serviceProviderId,startAddTime,endAddTime,consult,leaderId,groupId,manager,pageNum, pageSize);
    }

    @ApiOperation("删除潜在用户资料备注")
    @ApiImplicitParam(required = true, name = "remarksId", value = "备注id")
    @PostMapping("/remarks/delete/visit")
    public ResponseJson deleteVisitRemarks(String remarksId) {
        return clubService.deleteVisitRemarks(remarksId);
    }

    @ApiOperation("同步潜在用户到机构")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "clubId", value = "机构id"),
            @ApiImplicitParam(required = true, name = "questionManId", value = "咨询人id")
    })
    @PostMapping("/remarks/concact/visit")
    public ResponseJson concactVisitRemarks(String clubId, String questionManId) {
        return clubService.concactVisitRemarks(clubId, questionManId);
    }

    @ApiOperation("查询咨询类别")
    @ApiImplicitParams({
            @ApiImplicitParam(required = false, name = "consults", value = "咨询类别id,英文逗号拼接,可不传")
    })
    @PostMapping("/consults")
    public ResponseJson findConsults(String consults) {
        return clubService.findConsults(consults);
    }

    @ApiOperation("查询小组组长和总管理员")
    @PostMapping("/teams")
    public ResponseJson findTeams() {
        return clubService.findTeams();
    }

    @ApiOperation("根据组长协销id查组员")
    @ApiImplicitParams({
            @ApiImplicitParam(required = true, name = "leaderId", value = "组长协销id")
    })
    @PostMapping("/teams/groups")
    public ResponseJson findGroups(Integer leaderId) {
        return clubService.findGroups(leaderId);
    }

}
