package com.caimei365.user.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.aliyun.oss.OSS;
import com.aliyun.oss.OSSClientBuilder;
import com.caimei365.user.components.RedisService;
import com.caimei365.user.mapper.BaseMapper;
import com.caimei365.user.mapper.ClubMapper;
import com.caimei365.user.mapper.RegisterMapper;
import com.caimei365.user.mapper.SuperVipMapper;
import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.ClubRemarksDto;
import com.caimei365.user.model.dto.ClubUpdateDto;
import com.caimei365.user.model.dto.SuperVipDto;
import com.caimei365.user.model.po.SuperVipPo;
import com.caimei365.user.model.dto.JsonParamsDto;
import com.caimei365.user.model.po.RemarksFilePo;
import com.caimei365.user.model.po.ClubRemarksPo;
import com.caimei365.user.model.po.UserBeansHistoryPo;
import com.caimei365.user.model.po.UserPo;
import com.caimei365.user.model.vo.*;
import com.caimei365.user.service.ClubService;
import com.caimei365.user.utils.ImageUtils;
import com.caimei365.user.utils.MathUtil;
import com.caimei365.user.utils.OssUtil;
import com.github.pagehelper.Page;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.*;

import static com.alibaba.fastjson.JSON.parseArray;
import static com.alibaba.fastjson.JSON.parseObject;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/15
 */
@Slf4j
@Service
public class ClubServiceImpl implements ClubService {
    @Value("${caimei.wwwDomain}")
    private String wwwDomain;
    @Resource
    private ClubMapper clubMapper;
    @Resource
    private BaseMapper baseMapper;
    @Resource
    private RegisterMapper registerMapper;
    @Resource
    private SuperVipMapper vipMapper;
    @Resource
    private RedisService redisService;

    /**
     * 根据用户Id查询机构资料
     *
     * @param userId 用户Id
     * @return Map(userPo, clubPo)
     */
    @Override
    public ResponseJson<Map<String, Object>> getClubUserInfo(Integer userId) {
        if (null == userId) {
            return ResponseJson.error("参数异常：用户Id不能为空！", null);
        }
        // 用户信息
        UserVo user = baseMapper.getUserByUserId(userId);
        if (user == null) {
            return ResponseJson.error("用户信息不存在", null);
        }
        if (!StringUtils.isBlank(user.getAuditNote()) && 2 == user.getAuditStatus()) {
            if (user.getAuditNote().contains(",")) {
                List<String> list = Arrays.asList(user.getAuditNote().split(","));
                user.setAuditNoteList(list);
            } else {
                user.setAuditNoteList(Collections.singletonList(user.getAuditStatus().toString()));
            }
        }
        // 机构信息
        ClubVo club = clubMapper.getClubById(user.getClubId());
        if (club == null) {
            return ResponseJson.error("机构信息不存在", null);
        }
        if (null != club.getTownId()) {
            TownVo town = baseMapper.getTown(club.getTownId());
            CityVo city = baseMapper.getCity(town.getCityId());
            ProvinceVo province = baseMapper.getProvince(city.getProvinceId());
            club.setCityId(city.getCityId());
            club.setProvinceId(province.getProvinceId());
            club.setProvincialAddress(province.getName() + "" + city.getName() + "" + town.getName());
        }
        Map<String, Object> map = new HashMap(2);
        map.put("user", user);
        map.put("club", club);
        return ResponseJson.success(map);
    }

    /**
     * 修改机构资料
     *
     * @param club ClubUpgradeDto:{
     *             clubId                 机构ID
     *             userId                 用户ID
     *             name                   机构名称
     *             shortName                  机构简称(shortName)
     *             contractEmail          邮箱（contractEmail1）
     *             contractPhone          固定电话
     *             linkMan                联系人（linkMan1）
     *             provinceId             省Id
     *             cityId                 市Id
     *             townId                 县区Id
     *             address                地址
     *             shopPhoto              门头照(headpic)
     *             businessLicense        营业执照（businessLicenseImage）
     *             socialCreditCode       统一社会信用代码（socialCreditCode）
     *             firstClubType          一级分类：医美=1和生美=2
     *             secondClubType         医美的二级分类：诊所=1、门诊=2、医院=3。  生美没有二级分类
     *             department             医美分类下的门诊和医院则需要填写科室
     *             medicalPracticeLicense 医美分类必须上传医疗执业许可证（medicalPracticeLicenseImg）
     *             mainProduct            主打项目（mainpro）
     *             fax                    传真
     *             profile                公司简介
     *             }
     * @return ClubUpdateDto
     */
    @Override
    public ResponseJson<ClubUpdateDto> updateClubUserInfo(ClubUpdateDto club) {
        // 参数校验
        if (club.getUserId() == null) {
            return ResponseJson.error("参数异常：用户Id不能为空！", null);
        }
        if (club.getClubId() == null) {
            return ResponseJson.error("参数异常：机构Id不能为空！", null);
        }
        if (club.getLinkMan() == null) {
            return ResponseJson.error("参数异常：联系人不能为空！", null);
        }
        if (StringUtils.isNotBlank(club.getContractEmail())) {
            Integer userIdByEmail = baseMapper.getUserIdByEmail(club.getContractEmail());
            if (null != userIdByEmail && !userIdByEmail.equals(club.getUserId())) {
                return ResponseJson.error("该邮箱已被使用", null);
            }
        }
        UserPo user = new UserPo();
        // 用户Id
        user.setUserId(club.getUserId());
        // 用户名
        user.setUserName(club.getLinkMan());
        // 邮箱
        if (StringUtils.isNotBlank(club.getContractEmail())) {
            user.setEmail(club.getContractEmail());
        }
        // 机构名称
        if (StringUtils.isNotBlank(club.getName())) {
            user.setName(club.getName());
        }
        // 更新机构用户信息
        clubMapper.updateClubUserByUpdateInfo(user);
        // 更新机构信息
        clubMapper.updateClubByUpdateInfo(club);

        UserVo userVo = baseMapper.getUserByUserId(club.getUserId());
        if (userVo != null && userVo.getUserIdentity() == 4) {
            Integer id = clubMapper.findBeansHistoryByType(club.getUserId(), 3);
            boolean b = StringUtils.isNotBlank(club.getLinkMan()) && StringUtils.isNotBlank(club.getFax())
                    && StringUtils.isNotBlank(club.getContractPhone()) && StringUtils.isNotBlank(club.getProfile());
            if (b && id == null) {
                saveUserBeans(userVo);
            }
        } else if (userVo != null && userVo.getUserIdentity() == 2) {
            Integer id = clubMapper.findBeansHistoryByType(club.getUserId(), 4);
            boolean b = StringUtils.isNotBlank(club.getLinkMan()) && StringUtils.isNotBlank(club.getFax()) && club.getTownId() != null
                    && StringUtils.isNotBlank(club.getContractPhone()) && StringUtils.isNotBlank(club.getProfile()) && StringUtils.isNotBlank(club.getAddress())
                    && StringUtils.isNotBlank(club.getName()) && StringUtils.isNotBlank(club.getShortName()) && StringUtils.isNotBlank(club.getContractEmail())
                    && StringUtils.isNotBlank(club.getSocialCreditCode()) && StringUtils.isNotBlank(club.getBusinessLicense()) && StringUtils.isNotBlank(club.getShopPhoto())
                    && club.getFirstClubType() != null && StringUtils.isNotBlank(club.getMainProduct());
            if (b) {
                if (club.getFirstClubType() == 1) {
                    //医美
                    b = club.getSecondClubType() != null && StringUtils.isNotBlank(club.getMedicalPracticeLicense());
                    if (b && ("2".equals(club.getMedicalPracticeLicense()) || "3".equals(club.getMedicalPracticeLicense()))) {
                        b = StringUtils.isNotBlank(club.getDepartment());
                    }
                }
            }
            if (b && id == null) {
                saveUserBeans(userVo);
            }
        }

        return ResponseJson.success("修改机构资料成功", club);
    }

    private void saveUserBeans(UserVo user) {
        //机构完善资料,送500采美豆
        UserBeansHistoryPo beansHistory = new UserBeansHistoryPo();
        beansHistory.setUserId(user.getUserId());
        if (user.getUserIdentity() == 4) {
            //普通机构完善资料
            beansHistory.setBeansType(3);
        } else {
            //会员机构完善资料
            beansHistory.setBeansType(4);
        }
        beansHistory.setType(1);
        beansHistory.setNum(500);
        beansHistory.setPushStatus(0);
        beansHistory.setAddTime(new Date());
        registerMapper.insertBeansHistory(beansHistory);
        Integer userBeans = user.getUserBeans();
        userBeans = userBeans == null ? 500 : userBeans + 500;
        clubMapper.updateUserBeans(user.getUserId(), userBeans);
    }

    /**
     * 机构个人中心
     *
     * @param userId 用户Id
     * @return Map(userPo, clubPo)
     */
    @Override
    public ResponseJson<Map<String, Object>> getClubHomeData(Integer userId) {
        if (null == userId) {
            return ResponseJson.error("参数异常：用户Id不能为空！", null);
        }
        // 用户信息
        UserVo user = baseMapper.getUserByUserId(userId);
        if (user == null) {
            return ResponseJson.error("用户信息不存在", null);
        }
        ClubVo club = clubMapper.getClubById(user.getClubId());
        if (club == null) {
            return ResponseJson.error("机构信息不存在", null);
        }
        Map<String, Object> map = new HashMap<>(6);
        map.put("user", user);
        map.put("club", club);
//        OrderCountVo countVo = clubMapper.getOrderCount(userId);
//        //待确认数量
//        map.put("confirmedCount", countVo != null ? countVo.getConfirmedCount() : 0);
//        //待付款数量
//        map.put("paymentCount", countVo != null ? countVo.getPaymentCount() : 0);
//        //待发货数量
//        map.put("waitShipmentsCount", countVo != null ? countVo.getWaitShipmentsCount() : 0);
//        //已发货数量
//        map.put("shipmentsCount", countVo != null ? countVo.getShipmentsCount() : 0);
//        //退货款数量
//        map.put("salesReturnCount", countVo != null ? countVo.getSalesReturnCount() : 0);
        //联系电话
        String contactNumber = baseMapper.getAfterSalesPhone();
        map.put("contactNumber", contactNumber);
        //完善资料是否送豆
        boolean isModify = true;
        Integer id = null;
        if (user.getUserIdentity() == 4) {
            id = clubMapper.findBeansHistoryByType(userId, 3);
        } else if (user.getUserIdentity() == 2) {
            id = clubMapper.findBeansHistoryByType(userId, 4);
        }
        if (id != null && id > 0) {
            isModify = false;
        }
        map.put("isModify", isModify);
        //优惠券可用数量
        Integer couponNum = clubMapper.findCountCoupon(userId);
        //加入超级会员信息
        SuperVipDto vipDto = new SuperVipDto();
        SuperVipPo vip = vipMapper.findSuperVip(userId);
//        0未买过，-1过期，1有效
        if (vip == null) {
            vipDto.setVipFlag(0);
        } else {
            vipDto.setEndTime(vip.getEndTime());
            SuperVipPo endTime = vipMapper.findEndTime(userId);
            //不为空则有效期内
            if (endTime != null) {
                vipDto.setVipFlag(1);
                String format = new SimpleDateFormat("yyyy-MM-dd").format(endTime.getEndTime());
                vipDto.setTime(format);
            } else {
                vipDto.setVipFlag(-1);
                String format = new SimpleDateFormat("yyyy-MM-dd").format(vip.getEndTime());
                vipDto.setTime(format);
            }
        }
        map.put("vip", vipDto);
        map.put("couponNum", couponNum);
        return ResponseJson.success(map);
    }

    @Override
    public ResponseJson<BeansHistoryVo> beansPopUps(Integer userId) {
        BeansHistoryVo beansHistory = clubMapper.findBeansHistory(userId);
        if (beansHistory == null) {
            beansHistory = new BeansHistoryVo();
            //线上支付送豆
            Integer num = clubMapper.findByBeansType(userId, 6);
            beansHistory.setBeansType(6);
            if (num == null || num == 0) {
                //下单送豆
                num = clubMapper.findByBeansType(userId, 5);
                beansHistory.setBeansType(5);
            }
            beansHistory.setNum(num);
        }
        if (beansHistory.getNum() == null || beansHistory.getNum() == 0) {
            return ResponseJson.error("无推送", null);
        }
        clubMapper.updatePushStatus(userId);
        return ResponseJson.success(beansHistory);
    }

    @Override
    public ResponseJson<Map<String, Object>> beansHistory(Integer userId, Integer year, Integer month, Integer type, int pageNum, int pageSize) {
        Map<String, Object> map = new HashMap<>(2);
        UserVo user = baseMapper.getUserByUserId(userId);
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd");
        Calendar calendar = Calendar.getInstance();
        calendar.set(Calendar.YEAR, year);
        calendar.set(Calendar.MONTH, month - 1);
        calendar.set(Calendar.DAY_OF_MONTH, calendar.getMinimum(Calendar.DATE));
        String startTime = format.format(calendar.getTime()) + " 00:00:00";
        calendar.set(Calendar.DAY_OF_MONTH, calendar.getActualMaximum(Calendar.DATE));
        String endTime = format.format(calendar.getTime()) + " 23:59:59";
        PageHelper.startPage(pageNum, pageSize);
        List<BeansHistoryVo> historyList = clubMapper.findAllBeansHistory(userId, startTime, endTime, type);
        PageInfo<BeansHistoryVo> pageInfo = new PageInfo<>(historyList);
        map.put("pageInfo", pageInfo);
        map.put("userBeans", user.getUserBeans());
        return ResponseJson.success(map);
    }

    @Override
    public ResponseJson archiveDeduction(Integer userId, Integer archiveId) {
        // 查询是否已存在用户对该资料的抵扣记录
        Integer historyId = clubMapper.findBeansHistoryByArchiveId(userId, archiveId);
        if (null != historyId) {
            return ResponseJson.error(-1, "请勿重复抵扣");
        }
        // 查询用户采美豆数量
        Integer beansNum = clubMapper.getBeansNumByUserId(userId);
        if (null == beansNum || beansNum < 100) {
            return ResponseJson.error(-2, "抱歉，您的采美豆不足以抵扣，无法访问该商品资料");
        }
        UserBeansHistoryPo beansHistory = new UserBeansHistoryPo();
        beansHistory.setUserId(userId);
        beansHistory.setArchiveId(archiveId);
        beansHistory.setBeansType(13);
        beansHistory.setType(2);
        beansHistory.setNum(100);
        beansHistory.setPushStatus(0);
        beansHistory.setAddTime(new Date());
        registerMapper.insertBeansHistory(beansHistory);
        beansNum = beansNum - 100;
        clubMapper.updateUserBeans(userId, beansNum);
        return ResponseJson.success("抵扣成功");
    }

    /**
     * 保存机构资料备注
     *
     * @param jsonParamsDto:{ remarksId:           备注id,
     *                        机构id:               机构id,
     *                        serviceProviderId:   协销id,
     *                        questionMan:        咨询人姓名，
     *                        remarks:             文字备注,
     *                        fileList:    [{fileName:"文件名称",ossName:"oss文件名称"},{fileName:"文件名称",ossName:"oss文件名称"}...]
     *                        imageList:   ["图片","图片",...]
     *                        consult: (1,2) 咨询类别id，英文逗号隔开
     *                        }
     * @return
     */
    @Override
    public ResponseJson saveClubRemarks(JsonParamsDto jsonParamsDto) {
        try {
            JSONObject jsonObject = parseObject(jsonParamsDto.getParams());
            Integer clubId = jsonObject.getInteger("clubId");
            Integer remarksId = jsonObject.getInteger("remarksId");
            Integer serviceProviderId = jsonObject.getInteger("serviceProviderId");
            String remarks = jsonObject.getString("remarks");
            String consult = jsonObject.getString("consult");
            String questionMan = jsonObject.getString("questionMan");
            if (null == clubId) {
                return ResponseJson.error("参数异常，机构id不能为空");
            }
            if (null == serviceProviderId) {
                return ResponseJson.error("参数异常，协销id不能为空");
            }
            // 是否新增备注
            boolean newRemarks = null == remarksId;
            ClubRemarksPo clubRemarksPo = new ClubRemarksPo();
            clubRemarksPo.setRemarksId(remarksId);
            clubRemarksPo.setClubId(clubId);
            clubRemarksPo.setServiceProviderId(serviceProviderId);
            clubRemarksPo.setRemarks(remarks);
            clubRemarksPo.setQuestionMan(questionMan);
            clubRemarksPo.setConsult(consult);
            if (newRemarks) {
                // 新增备注
                clubMapper.insertRemarks(clubRemarksPo);
            } else {
                // 修改备注
                clubMapper.updateRemarks(clubRemarksPo);
                // 删除旧的备注图片和文件
                clubMapper.clearRemarksFiles(remarksId);
            }
            JSONArray filesArray = jsonObject.getJSONArray("fileList");
            JSONArray imagesArray = jsonObject.getJSONArray("imageList");
            remarksId = clubRemarksPo.getRemarksId();
            //保存图片
            if (!imagesArray.isEmpty()) {
                for (Object imageObj : imagesArray) {
                    String image = String.valueOf(imageObj);
                    // 保存资质图片
                    clubMapper.insertRemarksImage(remarksId, image);
                }
            }
            //保存文件
            if (!filesArray.isEmpty()) {
                for (Object fileObj : filesArray) {
                    JSONObject file = (JSONObject) fileObj;
                    String fileName = file.getString("fileName");
                    String ossName = file.getString("ossName");
                    // 保存资质文件
                    clubMapper.insertRemarksFile(remarksId, fileName, ossName);
                }
            }
            return ResponseJson.success("保存资料备注成功");
        } catch (Exception e) {
            log.info("保存机构资料备注参数:" + jsonParamsDto.toString());
            log.error("【保存机构资料备注】>>>参数解析异常try-catch:", e);
            return ResponseJson.error("保存机构资料备注参数解析异常！", null);
        }
    }

    @Override
    public ResponseJson<PaginationVo<RemarkVo>> getRemarksList(Integer serviceProviderId,
                                                               String keyWord,
                                                               String startAddTime,
                                                               String endAddTime,
                                                               String consult,
                                                               Integer leaderId,
                                                               Integer groupId,
                                                               Integer manager,
                                                               int pageNum, int pageSize) {
        if (null == serviceProviderId) {
            return ResponseJson.error("参数异常，协销id不能为空", null);
        }
        PageInfo<RemarksVo> pageInfo = null;
        Integer findLeader = clubMapper.findLeaderId(serviceProviderId);
        List<String> conss = new ArrayList<>();
        if(StringUtils.isNotBlank(consult)){
            if(consult.contains(",")){
                conss = Arrays.asList(consult.split(","));
            }else{
                conss.add(consult);
            }
        }
        if (null != manager && 1 == manager) {
            //主管查所有注册客户咨询记录
            List<String> finalConss = conss;
            pageInfo = PageHelper.startPage(pageNum, pageSize).doSelectPageInfo(() -> clubMapper.findAllRemarks(keyWord, startAddTime, endAddTime, leaderId, groupId, finalConss));
        } else if (null != findLeader && findLeader > 0) {
            List<String> finalConss1 = conss;
            pageInfo = PageHelper.startPage(pageNum, pageSize).doSelectPageInfo(() -> clubMapper.findAllRemarks(keyWord, startAddTime, endAddTime, serviceProviderId, groupId, finalConss1));
        } else {
            List<String> finalConss2 = conss;
            pageInfo = PageHelper.startPage(pageNum, pageSize).doSelectPageInfo(() -> clubMapper.getRemarksListByKey(keyWord, serviceProviderId,startAddTime,endAddTime, finalConss2));
        }
        ArrayList<RemarkVo> remarkVos = new ArrayList<>();
        pageInfo.getList().forEach(r -> {
            RemarkVo remarkVo = new RemarkVo();
            List<String> strings = new ArrayList<>();
            String rk = null == r.getRemarks() ? "" : r.getRemarks();
            if (rk.contains("，")) {
                String[] split = rk.split("，");
                strings = Arrays.asList(split);
            } else {
                strings.add(rk);
            }
            if (StringUtils.isNotBlank(r.getConsult())) {
                if (r.getConsult().contains(",")) {
                    String[] split = r.getConsult().split(",");
                    String Cons = "";
                    for (String con : split) {
                        Cons += clubMapper.findConsultById(con).getClassName() + ",";
                    }
                    Cons = Cons.substring(0, Cons.length() - 1);
                    remarkVo.setConsultBack(Cons);
                } else {
                    remarkVo.setConsultBack(clubMapper.findConsultById(r.getConsult()).getClassName());
                }
            }
            remarkVo.setLeaderName(r.getLeaderName());
            remarkVo.setRecordName(r.getRecordName());
            remarkVo.setServiceProviderId(r.getServiceProviderId());
            remarkVo.setRemarks(strings);
            remarkVo.setQuestionMan(r.getQuestionMan());
            remarkVo.setRemarksId(r.getRemarksId());
            remarkVo.setAddTime(r.getAddTime());
            remarkVo.setClubName(clubMapper.findClubName(r.getClubId()));
            remarkVo.setClubName(r.getClubName());
            remarkVo.setConsult(r.getConsult());
            remarkVos.add(remarkVo);
        });
        PaginationVo<RemarkVo> pageVo = new PaginationVo<>(remarkVos);
        if (null != remarkVos && remarkVos.size() > 0) {
            pageVo.setTotalRecord(remarkVos.size());
            if (remarkVos.size() > pageSize) {
                pageVo.setTotalPage((int) Math.ceil(MathUtil.div(remarkVos.size(), pageSize).doubleValue()));
                pageVo.setHasNextPage(true);
            } else {
                pageVo.setTotalPage(1);
                pageVo.setHasNextPage(false);
            }
        } else {
            pageVo.setTotalPage(0);
            pageVo.setHasNextPage(false);
            pageVo.setTotalRecord(0);
        }
        return ResponseJson.success(pageVo);
    }

    @Override
    public ResponseJson<RemarkVo> getRemarksDetail(Integer remarksId) {
        if (null == remarksId) {
            return ResponseJson.error("参数异常，备注id不能为空", null);
        }
        RemarksVo remarksVo = clubMapper.getRemarks(remarksId);
        List<String> imageList = clubMapper.getRemarksImageList(remarksId);
        List<RemarksFileVo> fileList = clubMapper.getRemarksFileList(remarksId);
        fileList.forEach(file -> file.setFileUrl(OssUtil.getOssUrl(file.getOssName())));
        List<String> strings = new ArrayList<>();
        String rk = null == remarksVo.getRemarks() ? "" : remarksVo.getRemarks();
        if (rk.contains("，")) {
            String[] split = rk.split("，");
            strings = Arrays.asList(split);
        } else {
            strings.add(rk);
        }
        RemarkVo remarkVo = new RemarkVo();
        remarkVo.setClubId(remarksVo.getClubId());
        remarkVo.setUserId(remarksVo.getUserId());
        remarkVo.setRemarksId(remarksVo.getRemarksId());
        remarkVo.setQuestionMan(remarksVo.getQuestionMan());
        remarkVo.setRemarks(strings);
        remarkVo.setFileList(fileList);
        remarkVo.setImageList(imageList);
        remarkVo.setAddTime(remarksVo.getAddTime());
        remarkVo.setConsult(remarksVo.getConsult());
        if (StringUtils.isNotBlank(remarkVo.getConsult())) {
            if (remarkVo.getConsult().contains(",")) {
                List<String> cons = Arrays.asList(remarkVo.getConsult().split(","));
                String Cons = "";
                for (String con : cons) {
                    Cons += clubMapper.findConsultById(con).getClassName() + ",";
                }
                Cons = Cons.substring(0, Cons.length() - 1);
                remarkVo.setConsultBack(Cons);
            } else {
                remarkVo.setConsultBack(clubMapper.findConsultById(remarkVo.getConsult()).getClassName());
            }
        }
        return ResponseJson.success(remarkVo);
    }

    @Override
    public ResponseJson deleteClubRemarks(Integer remarksId) {
        if (null == remarksId) {
            return ResponseJson.error("参数异常，备注id不能为空");
        }
        clubMapper.deleteRemarks(remarksId);
        //删除oss服务器上的文件
        List<RemarksFileVo> fileList = clubMapper.getRemarksFileList(remarksId);
        fileList.forEach(file -> {
            OssUtil.deleteSingleFile(file.getOssName());
        });
        //删除备注包含的文件
        clubMapper.deleteRemarksFiles(remarksId);
        return ResponseJson.success("删除成功");
    }

    /**
     * 机构个人中心数据
     *
     * @param userId 用户Id
     */
    @Override
    public ResponseJson<Map<String, Object>> getPersonalData(Integer userId) {
        Map<String, Object> result = new HashMap<>(8);
        // 1.用户信息
        UserVo user = baseMapper.getUserByUserId(userId);
        if (user == null) {
            return ResponseJson.error("用户信息不存在", null);
        }
        result.put("user", user);
        // 2.机构信息
        ClubVo club = clubMapper.getClubById(user.getClubId());
        if (club == null) {
            return ResponseJson.error("机构信息不存在", null);
        }
        result.put("club", club);
        // 3.售后无忧,购物须知
        AfterSaleVo afterSale = clubMapper.getAfterSale();
        result.put("afterSale", afterSale);
        // 4.资料完善度
        boolean identityFlag = (null != user.getUserIdentity() && (user.getUserIdentity() == 4 || user.getUserIdentity() == 2));
        if (!identityFlag) {
            return ResponseJson.error("用户身份错误", null);
        }
        // 会员机构
        boolean userFlag1 = (StringUtils.isNotBlank(club.getLinkMan()) && StringUtils.isNotBlank(user.getBindMobile()) && StringUtils.isNotBlank(club.getContractPhone()) && StringUtils.isNotBlank(club.getFax()) && StringUtils.isNotBlank(club.getProfile()) && StringUtils.isNotBlank(club.getName()) && StringUtils.isNotBlank(user.getEmail()) && StringUtils.isNotBlank(club.getShortName()) && club.getProvinceId() != null && club.getProvinceId() != 0 && club.getCityId() != null && club.getCityId() != 0 && club.getTownId() != null && club.getTownId() != 0 && StringUtils.isNotBlank(club.getAddress()) && StringUtils.isNotBlank(club.getSocialCreditCode()) && StringUtils.isNotBlank(club.getBusinessLicense()) && StringUtils.isNotBlank(club.getShopPhoto()) && null != club.getFirstClubType() && StringUtils.isNotBlank(club.getMainProduct()));
        // 普通机构
        boolean userFlag2 = (StringUtils.isNotBlank(club.getLinkMan()) && StringUtils.isNotBlank(user.getBindMobile()) && StringUtils.isNotBlank(club.getContractPhone()) && StringUtils.isNotBlank(club.getFax()) && StringUtils.isNotBlank(club.getProfile()));
        boolean degreeFlag = (user.getUserIdentity() == 4 && userFlag1) || (user.getUserIdentity() == 2 && userFlag2);
        if (degreeFlag) {
            result.put("degree", "100%");
        } else {
            result.put("degree", "80%");
        }
        // 5.未读消息数量
        Integer unReadMessageCount = clubMapper.getUnReadMessageCount(userId);
        result.put("unReadMessageCount", unReadMessageCount);
        // 6.优惠券可用数量
        Integer couponNum = clubMapper.getUserCouponCount(userId);
        result.put("couponNum", couponNum);
        // 7.今日推荐
        int floorId = 6;
        int index = 1;
        String homeAdvertiseKey = "user_advertise_" + floorId;
        if (!redisService.exists(homeAdvertiseKey)) {
            AdvertiseVo homePageAdvertise = new AdvertiseVo();
            homePageAdvertise.setAdvertiseTypeId(1001);
            homePageAdvertise.setTypeId(floorId);
            homePageAdvertise.setValidFlag("1");
            List<AdvertiseVo> list = clubMapper.getUserAdvertiseList(homePageAdvertise);
            for (AdvertiseVo advertise : list) {
                advertise.setImage(ImageUtils.getImageURL("homePageImages", advertise.getImage(), 0, wwwDomain));
            }
            redisService.setList(homeAdvertiseKey, list);
        }
        int pageSize = 4;
        int totalRecord = (int) redisService.listSize(homeAdvertiseKey);
        int total = totalRecord % pageSize == 0 ? totalRecord / pageSize : totalRecord / pageSize + 1;
        if (index > total) {
            index = index % total;
        }
        int begin = (index - 1) * pageSize;
        int end = index * pageSize - 1;
        //避免unchecked cast warning
        List<AdvertiseVo> list = new ArrayList<>();
        Object advertiseObj = redisService.getList(homeAdvertiseKey, begin, end);
        if (advertiseObj instanceof ArrayList<?>) {
            for (Object o : (List<?>) advertiseObj) {
                list.add((AdvertiseVo) o);
            }
        }
        result.put("homePageAdvertiseList", list);
        // 8.最新动态
        String informationKey = "home_info_" + floorId;
        redisService.remove(informationKey);
        if (!redisService.exists(informationKey)) {
            InformationVo info = new InformationVo();
            info.setInfoTypeId(1);
            info.setValidFlag("1");
            List<InformationVo> infoList = clubMapper.getInformationList(info);
            infoList.forEach(information -> information.setLink("/info/detail-" + information.getInformationId() + "-1.html"));
            redisService.setList(informationKey, infoList);
        }
        int infoIndex = 1;
        int infoPageSize = 5;
        int totalInfoRecord = (int) redisService.listSize(informationKey);
        int totalInfo = totalInfoRecord % infoPageSize == 0 ? totalInfoRecord / infoPageSize : totalInfoRecord / infoPageSize + 1;
        if (infoIndex > totalInfo) {
            infoIndex = infoIndex % totalInfo;
        }
        int infoBegin = (infoIndex - 1) * infoPageSize;
        int infoEnd = infoIndex * infoPageSize - 1;
        List<InformationVo> infoList = new ArrayList<>();
        Object infoObj = redisService.getList(informationKey, infoBegin, infoEnd);
        if (infoObj instanceof ArrayList<?>) {
            for (Object o : (List<?>) infoObj) {
                infoList.add((InformationVo) o);
            }
        }
        result.put("homePageInfoList", infoList);

        return ResponseJson.success(result);
    }

    @Override
    public ResponseJson<Map<String, String>> saveVisitorName(String name, String serviceProviderId) {
        //咨询人id
        String uuid = UUID.randomUUID().toString();
        VisitorRemarkVo visitor = new VisitorRemarkVo();
        visitor.setQuestionMan(name);
        visitor.setQuestionManId(uuid);
        visitor.setServiceProviderId(Integer.valueOf(serviceProviderId));
        clubMapper.insertQuestionMan(visitor);
        HashMap<String, String> result = new HashMap<>(2);
        result.put("questionManId", uuid);
        result.put("questionMan", name);
        return ResponseJson.success("添加成功", result);
    }

    @Override
    public ResponseJson<PaginationVo<VisitorRemarkVo>> getVisitorList(Integer serviceProviderId,
//                                                                      String keyWord,
//                                                                      String startAddTime,
//                                                                      String endAddTime,
//                                                                      String consult,
//                                                                      Integer leaderId,
//                                                                      Integer groupId,
//                                                                      Integer manager,
                                                                      int pageNum, int pageSize) {
        if (null == serviceProviderId) {
            return ResponseJson.error("参数异常，协销id不能为空", null);
        }
        List<VisitorRemarkVo> remarksList = new ArrayList<>();
//        List<String> conss = new ArrayList<>();
//        if(StringUtils.isNotBlank(consult)){
//            if(consult.contains(",")){
//                conss = Arrays.asList(consult.split(","));
//            }else{
//                conss.add(consult);
//            }
//        }
        PageHelper.startPage(pageNum, pageSize);
        remarksList = clubMapper.getVisitorList(serviceProviderId);
//        Integer findLeader = clubMapper.findLeaderId(serviceProviderId);
//        if (null != manager && 1 == manager) {
//            //主管查所有注册客户咨询记录
//            remarksList = clubMapper.getAllVisitRemark(keyWord, startAddTime, endAddTime, leaderId, groupId,conss);
//        } else if (null != findLeader && findLeader > 0) {
//            remarksList = clubMapper.getAllVisitRemark(keyWord, startAddTime, endAddTime, serviceProviderId, groupId,conss);
//        } else {
//            remarksList = clubMapper.getVisitorListByKey(serviceProviderId, keyWord,startAddTime, endAddTime,conss);
//        }
//        for (VisitorRemarkVo visitorRemarkVo : remarksList) {
//            if (StringUtils.isNotBlank(visitorRemarkVo.getConsult())) {
//                if (visitorRemarkVo.getConsult().contains(",")) {
//                    String[] split = visitorRemarkVo.getConsult().split(",");
//                    String Cons = "";
//                    for (String con : split) {
//                        Cons += clubMapper.findConsultById(con).getClassName() + ",";
//                    }
//                    Cons = Cons.substring(0, Cons.length() - 1);
//                    visitorRemarkVo.setConsultBack(Cons);
//                } else {
//                    visitorRemarkVo.setConsultBack(clubMapper.findConsultById(visitorRemarkVo.getConsult()).getClassName());
//                }
//            }
//        }
        return ResponseJson.success(new PaginationVo<>(remarksList));
    }

    @Override
    public ResponseJson<String> updateVisitor(String serviceProviderId, String questionMan, String questionManId) {
        clubMapper.updateQuestionMan(serviceProviderId, questionMan, questionManId);
        return ResponseJson.success("修改成功");
    }

    @Override
    public ResponseJson saveVisitRecord(JsonParamsDto visitor) {
        try {
            JSONObject jsonObject = parseObject(visitor.getParams());
            String questionManId = jsonObject.getString("questionManId");
            Integer remarksId = jsonObject.getInteger("remarksId");
            Integer serviceProviderId = jsonObject.getInteger("serviceProviderId");
            String remarks = jsonObject.getString("remarks");
            String consult = jsonObject.getString("consult");
            if (null == questionManId) {
                return ResponseJson.error("参数异常，咨询人id不能为空");
            }
            if (null == serviceProviderId) {
                return ResponseJson.error("参数异常，协销id不能为空");
            }
            // 是否新增备注
            boolean newRemarks = null == remarksId;
            VisitorRemarkVo visitorRemarkVo = new VisitorRemarkVo();
            visitorRemarkVo.setRemarksId(remarksId);
            visitorRemarkVo.setQuestionManId(questionManId);
            visitorRemarkVo.setServiceProviderId(serviceProviderId);
            visitorRemarkVo.setRemarks(remarks);
            visitorRemarkVo.setConsult(consult);
            visitorRemarkVo.setQuestionMan(clubMapper.findQuestionMan(questionManId));
            if (newRemarks) {
                // 新增备注
                clubMapper.insertVisitorRemark(visitorRemarkVo);
            } else {
                // 修改备注
                clubMapper.updateVisitorRemark(visitorRemarkVo);
                // 删除旧的备注图片和文件
                clubMapper.clearVisitorRemarks(remarksId);
            }
            JSONArray filesArray = jsonObject.getJSONArray("fileList");
            JSONArray imagesArray = jsonObject.getJSONArray("imageList");
            remarksId = visitorRemarkVo.getRemarksId();
            //保存图片
            if (!imagesArray.isEmpty()) {
                for (Object imageObj : imagesArray) {
                    String image = String.valueOf(imageObj);
                    // 保存资质图片
                    clubMapper.insertVisitorRemarksImage(remarksId, image);
                }
            }
            //保存文件
            if (!filesArray.isEmpty()) {
                for (Object fileObj : filesArray) {
                    JSONObject file = (JSONObject) fileObj;
                    String fileName = file.getString("fileName");
                    String ossName = file.getString("ossName");
                    // 保存资质文件
                    clubMapper.insertVisitorRemarksFile(remarksId, fileName, ossName);
                }
            }
            return ResponseJson.success("保存潜在用户资料成功");
        } catch (Exception e) {
            log.info("保存潜在用户资料备注参数:" + visitor.toString());
            log.error("【保存潜在用户资料备注】>>>参数解析异常try-catch:", e);
            return ResponseJson.error("保存潜在用户资料备注参数解析异常！", null);
        }
    }

    @Override
    public ResponseJson<VisitRemarkVo> getVisitRemark(Integer remarksId) {
        if (null == remarksId) {
            return ResponseJson.error("参数异常，备注id不能为空", null);
        }
        VisitorRemarkVo visitRemarksVo = clubMapper.getVisitRemark(remarksId);
        List<String> imageList = clubMapper.getVisitRemarksImageList(remarksId);
        List<RemarksFileVo> fileList = clubMapper.getVisitRemarksFileList(remarksId);
        fileList.forEach(file -> file.setFileUrl(OssUtil.getOssUrl(file.getOssName())));
        List<String> strings = new ArrayList<>();
        String rk = null == visitRemarksVo.getRemarks() ? "" : visitRemarksVo.getRemarks();
        if (rk.contains("，")) {
            String[] split = rk.split("，");
            strings = Arrays.asList(split);
        } else {
            strings.add(rk);
        }
        VisitRemarkVo visit = new VisitRemarkVo();
        visit.setConsult(visitRemarksVo.getConsult());
        visit.setQuestionMan(visitRemarksVo.getQuestionMan());
        visit.setQuestionManId(visitRemarksVo.getQuestionManId());
        visit.setRemarksId(visitRemarksVo.getRemarksId());
        visit.setRemarks(strings);
        visit.setAddDate(visitRemarksVo.getAddDate());
        visit.setImageList(imageList);
        visit.setFileList(fileList);
        if (StringUtils.isNotBlank(visitRemarksVo.getConsult())) {
            if (visitRemarksVo.getConsult().contains(",")) {
                List<String> cons = Arrays.asList(visitRemarksVo.getConsult().split(","));
                String Cons = "";
                for (String con : cons) {
                    Cons += clubMapper.findConsultById(con).getClassName() + ",";
                }
                Cons = Cons.substring(0, Cons.length() - 1);
                visit.setConsultBack(Cons);
            } else {
                visit.setConsultBack(clubMapper.findConsultById(visitRemarksVo.getConsult()).getClassName());
            }
        }
        return ResponseJson.success(visit);
    }

    @Override
    public ResponseJson<PaginationVo<VisitRemarkVo>> getVisitorRecordList(String questionManId, String keyWord, Integer serviceProviderId, String startAddTime, String endAddTime, String consult, Integer leaderId, Integer groupId, Integer manager, int pageNum, int pageSize) {
        PageInfo<VisitorRemarkVo> remarksList = null;
        List<String> conss = new ArrayList<>();
        if(StringUtils.isNotBlank(consult)){
            if(consult.contains(",")){
                conss = Arrays.asList(consult.split(","));
            }else{
                conss.add(consult);
            }
        }
        Integer findLeader = clubMapper.findLeaderId(serviceProviderId);
        if (null != manager && 1 == manager) {
            //主管查所有注册客户咨询记录
            List<String> finalConss = conss;
            remarksList = PageHelper.startPage(pageNum, pageSize).doSelectPageInfo(() -> clubMapper.getAllVisitRemark(keyWord, startAddTime, endAddTime, leaderId, groupId, finalConss));
        } else  if (null != findLeader && findLeader > 0) {
            List<String> finalConss1 = conss;
            remarksList = PageHelper.startPage(pageNum, pageSize).doSelectPageInfo(() -> clubMapper.getAllVisitRemark(keyWord, startAddTime, endAddTime, serviceProviderId, groupId, finalConss1));
        }else {
            List<String> finalConss2 = conss;
            remarksList = PageHelper.startPage(pageNum, pageSize).doSelectPageInfo(() ->clubMapper.getVisitorListByKey(serviceProviderId, keyWord,startAddTime, endAddTime, finalConss2));
        }
        ArrayList<VisitRemarkVo> remarkVos = new ArrayList<>();
        remarksList.getList().forEach(r -> {
            VisitRemarkVo visit = new VisitRemarkVo();
            List<String> strings = new ArrayList<>();
            String rk = null == r.getRemarks() ? "" : r.getRemarks();
            if (rk.contains("，")) {
                String[] split = rk.split("，");
                strings = Arrays.asList(split);
            } else {
                strings.add(rk);
            }
            if (StringUtils.isNotBlank(r.getConsult())) {
                if (r.getConsult().contains(",")) {
                    String[] split = r.getConsult().split(",");
                    String Cons = "";
                    for (String con : split) {
                        Cons += clubMapper.findConsultById(con).getClassName() + ",";
                    }
                    Cons = Cons.substring(0, Cons.length() - 1);
                    visit.setConsultBack(Cons);
                } else {
                    visit.setConsultBack(clubMapper.findConsultById(r.getConsult()).getClassName());
                }
            }
            if(StringUtils.isBlank(r.getQuestionMan())){
                visit.setQuestionMan(clubMapper.findQuestionMan(r.getQuestionManId()));
            }else{
                visit.setQuestionMan(r.getQuestionMan());
            }
            visit.setLeaderName(r.getLeaderName());
            visit.setRemarks(strings);
            visit.setAddDate(r.getAddDate());
            visit.setRemarksId(r.getRemarksId());
            visit.setQuestionManId(r.getQuestionManId());
            visit.setServiceProviderId(r.getServiceProviderId());
            visit.setRecordName(r.getRecordName());
            visit.setConsult(r.getConsult());
            remarkVos.add(visit);
        });
        PaginationVo<VisitRemarkVo> pageVo = new PaginationVo<>(remarkVos);
        if (null != remarkVos && remarkVos.size() > 0) {
            pageVo.setTotalRecord(remarkVos.size());
            if (remarkVos.size() > pageSize) {
                pageVo.setTotalPage((int) Math.ceil(MathUtil.div(remarkVos.size(), pageSize).doubleValue()));
                pageVo.setHasNextPage(true);
            } else {
                pageVo.setTotalPage(1);
                pageVo.setHasNextPage(false);
            }
        } else {
            pageVo.setTotalPage(0);
            pageVo.setHasNextPage(false);
            pageVo.setTotalRecord(0);
        }
        return ResponseJson.success(pageVo);
    }

    @Override
    public ResponseJson deleteVisitRemarks(String remarksId) {
        if (null == remarksId) {
            return ResponseJson.error("参数异常，备注id不能为空");
        }
        clubMapper.deleteVisitRemark(Integer.valueOf(remarksId));
        //删除oss服务器上的文件
        List<RemarksFileVo> fileList = clubMapper.getVisitRemarksFileList(Integer.valueOf(remarksId));
        fileList.forEach(file -> {
            OssUtil.deleteSingleFile(file.getOssName());
        });
        //删除备注包含的文件
        clubMapper.clearVisitorRemarks(Integer.valueOf(remarksId));
        return ResponseJson.success("删除成功");
    }

    @Override
    public ResponseJson concactVisitRemarks(String clubId, String questionManId) {
        if (null == clubId || "".equals(clubId)) {
            return ResponseJson.error("参数异常，机构id不能为空");
        }
        if (null == questionManId || "".equals(questionManId)) {
            return ResponseJson.error("参数异常，咨询人id不能为空");
        }
        //根据咨询人查cm_visitor_remarks赋值clubid，concactTime
        clubMapper.updateVisit(questionManId, clubId);
        //cm_visitor_remarks搬运到cm_club_remarks，cm_visitor_remarks_file搬运到cm_club_remarks_file
        List<VisitorRemarkVo> visits = clubMapper.findConcactVisit(questionManId);
        visits.forEach(v -> {
            List<String> imageList = clubMapper.getVisitRemarksImageList(v.getRemarksId());
            List<RemarksFileVo> fileList = clubMapper.getVisitRemarksFileList(v.getRemarksId());
            String questionMan = clubMapper.findQuestionMan(v.getQuestionManId());
            RemarksVo remarksVo = new RemarksVo();
            remarksVo.setRemarks(v.getRemarks());
            remarksVo.setClubId(Integer.valueOf(v.getClubId()));
            remarksVo.setQuestionMan(questionMan);
            remarksVo.setAddTime(v.getAddDate());
            remarksVo.setServiceProviderId(v.getServiceProviderId());
            remarksVo.setConsult(v.getConsult());
            clubMapper.concactVisit(remarksVo);
            if (null != imageList && imageList.size() > 0) {
                imageList.forEach(i -> clubMapper.insertRemarksImage(remarksVo.getRemarksId(), i));
            }
            if (null != fileList && fileList.size() > 0) {
                fileList.forEach(f -> clubMapper.insertRemarksFile(remarksVo.getRemarksId(), f.getFileName(), f.getOssName()));
            }
        });
        return ResponseJson.success("同步成功");
    }

    @Override
    public ResponseJson findConsults(String consults) {
        if (StringUtils.isBlank(consults)) {
            //如果传空，查所有咨询类别
            List<ConsultVo> list = clubMapper.findConsult();
            return ResponseJson.success(list);
        } else {
            //不传空判断逗号
            if (consults.contains(",")) {
                List<String> strings = Arrays.asList(consults.split(","));
                List<ConsultVo> consultVos = new ArrayList<>();
                for (String string : strings) {
                    consultVos.add(clubMapper.findConsultById(string));
                }
                return ResponseJson.success(consultVos);
            } else {
                return ResponseJson.success(clubMapper.findConsultById(consults));
            }
        }
    }

    @Override
    public ResponseJson findTeams() {
        List<TeamLederVo> list = clubMapper.findAllTeams();
        return ResponseJson.success(list);
    }

    @Override
    public ResponseJson findGroups(Integer leaderId) {
        List<TeamGroupVo> groups = clubMapper.findGroups(leaderId);
        return ResponseJson.success(groups);
    }
}
