package com.caimei365.user.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.caimei365.user.feign.CommodityFeign;
import com.caimei365.user.mapper.*;
import com.caimei365.user.model.ResponseJson;
import com.caimei365.user.model.dto.BaikeProductDto;
import com.caimei365.user.model.dto.ShopArticleDto;
import com.caimei365.user.model.dto.ShopBannerDto;
import com.caimei365.user.model.dto.ShopUpdateDto;
import com.caimei365.user.model.po.*;
import com.caimei365.user.model.vo.*;
import com.caimei365.user.service.ShopService;
import com.caimei365.user.utils.DateUtil;
import com.caimei365.user.utils.GenerateUtils;
import com.caimei365.user.utils.ImageUtils;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;

/**
 * Description
 *
 * @author : Charles
 * @date : 2021/3/9
 */
@Slf4j
@Service
public class ShopServiceImpl implements ShopService {
    @Value("${caimei.wwwDomain}")
    private String wwwDomain;
    @Resource
    private CommodityFeign commodityFeign;
    @Resource
    private BaseMapper baseMapper;
    @Resource
    private ShopMapper shopMapper;
    @Resource
    private ArticleMapper articleMapper;
    @Resource
    private BaikeProductMapper baikeProductMapper;
    @Resource
    private PersonalCenterMapper personalCenterMapper;
    @Value("${spring.cloud.config.profile}")
    private String active;


    /**
     * 根据用户Id查询供应商资料
     *
     * @param userId 用户Id
     *
     * @return Map(userPo,clubPo)
     */
    @Override
    public ResponseJson<Map<String, Object>> getShopUserInfo(Integer userId) {
        if (null == userId) {
            return ResponseJson.error("参数异常：用户Id不能为空！", null);
        }
        // 用户信息
        UserVo user = baseMapper.getUserByUserId(userId);
        if (user == null) {
            return ResponseJson.error("用户信息不存在", null);
        }
        if (!StringUtils.isBlank(user.getAuditNote()) && 2 == user.getAuditStatus()) {
            if (user.getAuditNote().contains(",")) {
                List<String> list = Arrays.asList(user.getAuditNote().split(","));
                user.setAuditNoteList(list);
            } else {
                user.setAuditNoteList(Collections.singletonList(user.getAuditStatus().toString()));
            }
        }
        // 供应商信息
        ShopVo shop = shopMapper.getShopById(user.getShopId());
        if (shop == null) {
            return ResponseJson.error("供应商信息不存在", null);
        }
        if (null != shop.getTownId()) {
            TownVo town = baseMapper.getTown(shop.getTownId());
            CityVo city = baseMapper.getCity(town.getCityId());
            ProvinceVo province = baseMapper.getProvince(city.getProvinceId());
            shop.setCityId(city.getCityId());
            shop.setProvinceId(province.getProvinceId());
            shop.setProvincialAddress(province.getName() + "" + city.getName() + "" + town.getName());
        }
        // 荣誉证书
        List<String> honorCertification = shopMapper.getShopCert(user.getShopId(), 1);
        shop.setHonorCertification(honorCertification);
        // 生产经营证书
        List<String> operationLicence = shopMapper.getShopCert(user.getShopId(), 2);
        if (null != operationLicence && operationLicence.size() > 0) {
            shop.setOperationLicence(operationLicence.get(0));
        }
        // 产品证书
        List<String> productCertification = shopMapper.getShopCert(user.getShopId(), 3);
        shop.setProductCertification(productCertification);
        // 卫生许可证
        List<String> hygienicLicense = shopMapper.getShopCert(user.getShopId(), 5);
        if (null != hygienicLicense && hygienicLicense.size() > 0) {
            shop.setHygienicLicense(hygienicLicense.get(0));
        }
        // 税务登记证
        List<String> taxLicense = shopMapper.getShopCert(user.getShopId(), 6);
        if (null != taxLicense && taxLicense.size() > 0) {
            shop.setTaxLicense(taxLicense.get(0));
        }
        HashMap<String, Object> map = new HashMap(2);
        map.put("user", user);
        map.put("shop", shop);
        return ResponseJson.success(map);
    }


    /**
     * 修改供应商资料
     *
     * @param shopUpdateDto ShopUpdateDto{
     *                        shopId                    供应商Id
     *                        userId                    用户Id
     *                        name                      组织名称
     *                        shortName                     供应商公司简称(shortName)
     *                        email                     邮箱
     *                        contractPhone             固定电话
     *                        linkMan                   联系人
     *                        provinceId                省(provinceID)
     *                        cityId                    市(cityID)
     *                        townId                    所在县区Id(townID)
     *                        address                   地址
     *                        socialCreditCode          统一社会信用代码(营业执照编号)
     *                        businessLicense           营业执照(businessLicenseImage)
     *                        firstShopType             医疗=1和非医疗=2
     *                        secondShopType            医疗的二级分类 一类器械=1、二类器械 =2、三类器械=3、其他=4 /// 1和非医疗没有二级分类
     *                        mainProduct               主打项目(mainpro)
     *                        mainProductDesc           主打商品说明(productDesc)
     *                        legalPerson               法人代表
     *                        registeredCapital         注册资本
     *                        faxNumber                 传真号(fax)
     *                        companyNature             传真号(nature)
     *                        turnover                  年营业额
     *                        medicalPracticeLicenseImg 医疗执业许可证(medicalPracticeLicenseImg1)
     *                        shopDesc                  公司介绍(info)
     *                        businessScope             经营范围
     *                        logo                      公司LOGO
     *                    }
     * @param operationLicence          生产经营证书(productionLicence)
     * @param hygienicLicense           卫生许可证
     * @param taxLicense                税务登记证
     * @param honorCertification        荣誉证书(certificateHonor)
     * @param productCertification      产品证书
     * @return ClubUpdateDto
     */
    @Override
    public ResponseJson<Void> updateShopUserInfo(ShopUpdateDto shopUpdateDto, String operationLicence, String hygienicLicense, String taxLicense, String honorCertification, String productCertification) {
        // 参数校验
        if (null == shopUpdateDto.getUserId()) {
            return ResponseJson.error("参数异常：用户Id不能为空！");
        }
        if (null == shopUpdateDto.getShopId()) {
            return ResponseJson.error("参数异常：供应商Id不能为空！");
        }
        if (StringUtils.isNotBlank(shopUpdateDto.getContractEmail())) {
            Integer userIdByEmail = baseMapper.getUserIdByEmail(shopUpdateDto.getContractEmail());
            if (null != userIdByEmail && !userIdByEmail.equals(shopUpdateDto.getUserId())) {
                return ResponseJson.error("该邮箱已被使用");
            }
        }
        /*
            组装用户数据 user
         */
        UserPo user = new UserPo();
        user.setUserId(shopUpdateDto.getUserId());
        user.setName(shopUpdateDto.getName());
        user.setUserName(shopUpdateDto.getShortName());
        user.setEmail(shopUpdateDto.getContractEmail());
        // 更新供应商用户信息
        shopMapper.updateShopUserByUpdateInfo(user);
        // 更新供应商信息
        shopMapper.updateShopByUpdateInfo(shopUpdateDto);
        if (StringUtils.isNotBlank(shopUpdateDto.getSocialCreditCode())) {
            // 清除数据库证书数据
            shopMapper.deleteShopCertByShopId(shopUpdateDto.getShopId());
            ShopCertPo shopCert = new ShopCertPo();
            shopCert.setShopId(shopUpdateDto.getShopId());
            shopCert.setShopCertTypeId(2);
            shopCert.setImage(operationLicence);
            shopCert.setName("生产经营证书");
            // 保存生产经营证书
            shopMapper.insertShopCert(shopCert);
            shopCert.setShopCertTypeId(5);
            shopCert.setImage(hygienicLicense);
            shopCert.setName("卫生许可证");
            // 保存卫生许可证
            shopMapper.insertShopCert(shopCert);
            shopCert.setShopCertTypeId(6);
            shopCert.setImage(taxLicense);
            shopCert.setName("税务登记证");
            // 保存税务登记证
            shopMapper.insertShopCert(shopCert);
            if (StringUtils.isNotBlank(honorCertification)) {
                String[] images = honorCertification.split(",");
                for (String image : images) {
                    if (StringUtils.isNotBlank(image)) {
                        shopCert.setShopCertTypeId(1);
                        shopCert.setImage(image);
                        shopCert.setName("荣誉证书");
                        // 保存荣誉证书
                        shopMapper.insertShopCert(shopCert);
                    }
                }
            }
            if (StringUtils.isNotBlank(productCertification)) {
                String[] images = productCertification.split(",");
                for (String image : images) {
                    if (StringUtils.isNotBlank(image)) {
                        shopCert.setShopCertTypeId(3);
                        shopCert.setImage(image);
                        shopCert.setName("产品证书");
                        // 保存产品证书
                        shopMapper.insertShopCert(shopCert);
                    }
                }
            }
        }
        return ResponseJson.success("修改供应商资料成功", null);
    }

    /**
     * 供应商首页数据
     *
     * @param shopId 供应商Id
     */
    @Override
    public ResponseJson<ShopHomeVo> getShopHomeData(Integer shopId) {
        ShopHomeVo supplier = shopMapper.getShopHomeData(shopId);
        if (supplier != null && supplier.getBusinessScope() != null) {
            String[] businessScope = supplier.getBusinessScope().split("/");
            supplier.setBusinessScopeArr(businessScope);
            supplier.setLogo(ImageUtils.getImageURL("shopLogo", supplier.getLogo(), 0, wwwDomain));
        }
        //公司资质照片
        List<String> productionLicence = shopMapper.getShopCertById(shopId, 2);
        if (null != productionLicence && productionLicence.size() > 0) {
            supplier.setMedicalPracticeLicenseImg1(productionLicence.get(0));
        }
        List<String> hygienicLicense = shopMapper.getShopCertById(shopId, 5);
        if (null != hygienicLicense && hygienicLicense.size() > 0) {
            supplier.setMedicalPracticeLicenseImg2(hygienicLicense.get(0));
        }
        List<String> taxLicense = shopMapper.getShopCertById(shopId, 6);
        if (null != taxLicense && taxLicense.size() > 0) {
            supplier.setMedicalPracticeLicenseImg3(taxLicense.get(0));
        }
        return ResponseJson.success(supplier);
    }

    /**
     * 供应商首页-轮播图片
     *
     * @param shopId 供应商Id
     */
    @Override
    public ResponseJson<List<ShopBannerVo>> getShopHomeImages(Integer shopId) {
        List<ShopBannerVo> images = shopMapper.getShopHomeImages(shopId);
        return ResponseJson.success(images);
    }

    /**
     * 供应商-更新轮播图片
     *
     * @param shopBannerDto {
     *                      id      图片id
     *                      shopId  供应商Id
     *                      image   图片
     *                      title   名称
     *                      link    链接
     *                      info    描述
     *                      }
     */
    @Override
    public ResponseJson<Void> saveShopHomeImages(ShopBannerDto shopBannerDto) {
        ShopBannerVo shopBanner = new ShopBannerVo();
        BeanUtils.copyProperties(shopBannerDto, shopBanner);
        if (null != shopBannerDto.getId()){
            // 更新
            shopBanner.setId(shopBannerDto.getId());
            shopMapper.updateShopHomeImage(shopBanner);
        } else {
            // 新增
            int count = shopMapper.getShopHomeImageCount(shopBannerDto.getShopId());
            if (count >= 4) {
                return ResponseJson.error("主页广告图的上限是4张图！", null);
            }
            shopMapper.insertShopHomeImage(shopBanner);
        }
        return ResponseJson.success(null);
    }

    /**
     * 供应商-删除轮播图片
     *
     * @param id  图片id
     */
    @Override
    public ResponseJson<Void> deleteShopHomeImages(Integer id) {
        shopMapper.deleteShopHomeImage(id);
        return ResponseJson.success(null);
    }

    /**
     * 供应商个人中心数据
     *
     * @param userId 用户Id
     */
    @Override
    public ResponseJson<Map<String, Object>> getShopPersonalData(Integer userId) {
        Map<String, Object> result = new HashMap<>(11);
        // 1.用户信息
        UserVo user = baseMapper.getUserByUserId(userId);
        if (user == null) {
            return ResponseJson.error("用户信息不存在", null);
        }
        result.put("user", user);
        // 2.供应商信息
        ShopVo shop = shopMapper.getShopById(user.getShopId());
        if (shop == null) {
            return ResponseJson.error("供应商信息不存在", null);
        }
        shop.setLogo(ImageUtils.getImageURL("shopLogo", shop.getLogo(), 0, wwwDomain));
        result.put("shop", shop);
        // 3.资料完整度
        List<String> productCertification = shopMapper.getShopCertById(user.getShopId(), 3);
        List<String> certificateHonor = shopMapper.getShopCertById(user.getShopId(), 1);
        // 4.是否有荣誉证书与产品证书
        boolean b = productCertification != null && productCertification.size() > 0 && certificateHonor != null && certificateHonor.size() > 0;
        if (StringUtils.isNotBlank(user.getEmail()) && StringUtils.isNotBlank(shop.getLegalPerson()) && StringUtils.isNotBlank(shop.getShopDesc())
                && StringUtils.isNotBlank(shop.getLogo()) && b) {
            result.put("dataIntegrity", "100%");
        } else if (StringUtils.isNotBlank(shop.getLegalPerson()) && StringUtils.isNotBlank(shop.getShopDesc()) && StringUtils.isNotBlank(shop.getLogo())) {
            result.put("dataIntegrity", "90%");
        } else {
            result.put("dataIntegrity", "70%");
        }
        // 5.店铺促销活动
        PromotionsVo promotions = shopMapper.getShopPromotionsByShopId(user.getShopId());
        if (null != promotions && 3 == promotions.getMode()) {
            List<ProductItemVo> productGifts = shopMapper.getPromotionsGifts(promotions.getId());
            productGifts.forEach(p -> {
                p.setImage(ImageUtils.getImageURL("product", p.getImage(), 0, wwwDomain));
            });
            promotions.setGiftList(productGifts);
        }
        result.put("promotions", promotions);
        // 6.未读消息数量
        Integer unReadMessageCount = personalCenterMapper.getUnReadMessageCount(userId);
        result.put("unReadMessageCount", unReadMessageCount);
        // 7.商品数量统计,validFlag 商品状态，见ProductStatus，0逻辑删除 1待审核 2已上架 3已下架 8审核未通过 9已冻结'
        Integer allNum = shopMapper.getShopProductCount(user.getShopId(), null);
        result.put("allNum", allNum);
        // 8.已上架数量
        Integer upNum = shopMapper.getShopProductCount(user.getShopId(), 2);
        result.put("upNum", upNum);
        // 9.已下架数量
        Integer downNum = shopMapper.getShopProductCount(user.getShopId(), 3);
        result.put("downNum", downNum);
        // 10.单品销售排名
        List<Map<String, Object>> salesRankingList = shopMapper.getSalesRankingList(user.getShopId());
        if (salesRankingList != null && salesRankingList.size() > 0) {
            salesRankingList.forEach(map -> {
                ProductItemVo product = shopMapper.getProductShown((Integer) map.get("productId"));
                if (product != null) {
                    map.put("name", product.getName());
                    map.put("image", ImageUtils.getImageURL("product", product.getImage(), 0, wwwDomain));
                }
            });
        }
        result.put("salesRankingList", salesRankingList);
        // 11.销售情况统计
        List<Map<String, Object>> salesStatisticsList = new ArrayList<>();
        Date endDayOfDay = DateUtil.getDayEnd();
        // 近一个月销售情况统计
        Date beginDayOfYesterday = DateUtil.addMonth(endDayOfDay, -1);
        Map<String, Object> m1 = shopMapper.getSalesStatistics(user.getShopId(), DateUtil.formatDateTime(beginDayOfYesterday), DateUtil.formatDateTime(endDayOfDay));
        m1.put("time", "近一月");
        salesStatisticsList.add(m1);
        // 近三个月销售情况统计
        Date beginDayOfLastWeek = DateUtil.addMonth(endDayOfDay, -3);
        Map<String, Object> m2 = shopMapper.getSalesStatistics(user.getShopId(), DateUtil.formatDateTime(beginDayOfLastWeek), DateUtil.formatDateTime(endDayOfDay));
        m2.put("time", "近三月");
        salesStatisticsList.add(m2);
        // 近半年销售情况统计
        Date beginDayOfLastMonth = DateUtil.addMonth(endDayOfDay, -6);
        Map<String, Object> m3 = shopMapper.getSalesStatistics(user.getShopId(), DateUtil.formatDateTime(beginDayOfLastMonth), DateUtil.formatDateTime(endDayOfDay));
        m3.put("time", "近半年");
        salesStatisticsList.add(m3);
        // 近一年销售情况统计
        Date beginDayOfLastYear = DateUtil.addMonth(endDayOfDay, -12);
        Map<String, Object> m4 = shopMapper.getSalesStatistics(user.getShopId(), DateUtil.formatDateTime(beginDayOfLastYear), DateUtil.formatDateTime(endDayOfDay));
        m4.put("time", "近一年");
        salesStatisticsList.add(m4);
        result.put("salesStatisticsList", salesStatisticsList);

        return ResponseJson.success(result);
    }

    @Override
    public ResponseJson<Map<String, Object>> getShopArticleById(Integer articleId) {
        Map<String, Object> map = new HashMap<>(2);
        // 供应商文章
        ShopArticleVo shopArticle = articleMapper.getShopArticleById(articleId);
        // 文章分类列表
        List<ArticleTypeVo> articleTypeList = articleMapper.getArticleTypeList();
        // 文章标签列表
        String articleLabels = articleMapper.getArticleLabelList();
        map.put("shopArticle", shopArticle);
        map.put("articleTypeList", articleTypeList);
        map.put("articleLabels", articleLabels);
        return ResponseJson.success(map);
    }

    @Override
    public ResponseJson<Void> saveShopArticle(ShopArticleDto shopArticleDto) {
        // 参数校验
        if (null == shopArticleDto.getShopId()) {
            return ResponseJson.error("参数异常，供应商id不能为空", null);
        }
        if (StringUtils.isEmpty(shopArticleDto.getTitle())) {
            return ResponseJson.error("参数异常，文章标题不能为空", null);
        }
        if (StringUtils.isEmpty(shopArticleDto.getLabel())) {
            return ResponseJson.error("参数异常，文章标签不能为空", null);
        }
        if (StringUtils.isEmpty(shopArticleDto.getKeyword())) {
            return ResponseJson.error("参数异常，SEO关键词不能为空", null);
        }
        if (StringUtils.isEmpty(shopArticleDto.getPublisher())) {
            return ResponseJson.error("参数异常，发布人不能为空", null);
        }
        if (StringUtils.isEmpty(shopArticleDto.getRecommendContent())) {
            return ResponseJson.error("参数异常，推荐语不能为空", null);
        }
        if (StringUtils.isEmpty(shopArticleDto.getArticleContent())) {
            return ResponseJson.error("参数异常，文章内容不能为空", null);
        }
        if (null == shopArticleDto.getTypeId()) {
            return ResponseJson.error("参数异常，文章分类不能为空", null);
        }
        if (StringUtils.isEmpty(shopArticleDto.getGuidanceImage())) {
            return ResponseJson.error("参数异常，引导图不能为空", null);
        }
        if (null == shopArticleDto.getStatus()) {
            return ResponseJson.error("参数异常，状态不能为空", null);
        }
        // 保存新增的文章标签
        String articleLabel = shopArticleDto.getLabel();
        String[] labelArr = articleLabel.split(",");
        for (String label : labelArr) {
            Integer dbLabelId = articleMapper.getArticleLabelId(label);
            if (null == dbLabelId) {
                articleMapper.insertArticleLabel(label);
            }
        }
        ArticlePo articlePo = new ArticlePo();
        BeanUtils.copyProperties(shopArticleDto, articlePo);
        // 新增文章标识
        boolean newArticleFlag = null == articlePo.getArticleId() || 0 == articlePo.getArticleId();
        // 保存供应商文章
        if (newArticleFlag) {
            articlePo.setPublishSource(2);
            articlePo.setRecommendStatus(0);
            articlePo.setBasePraise(0);
            articlePo.setBasePv(0);
            articlePo.setPriorityIndex(0);
            articlePo.setAuditStatus(1);
            articlePo.setOnlineStatus(1);
            articleMapper.insertShopArticle(articlePo);
        } else {
            articlePo.setAuditStatus(1);
            articlePo.setOnlineStatus(1);
            articleMapper.updateShopArticle(articlePo);
        }
        // 更新文章索引
        commodityFeign.updateArticleIndex(articlePo.getArticleId());
        if (newArticleFlag) {
            // 新增文章浏览/点赞记录
            articleMapper.insertArticlePraise(articlePo.getArticleId());
            // 新增文章 百度链接实时推送
            if ("prod".equals(active)) {
                GenerateUtils.pushBaiduLink("https://www.caimei365.com/info/detail-"+articlePo.getArticleId()+"-1.html");
            }
        }
        return ResponseJson.success(null);
    }

    @Override
    public ResponseJson<PageInfo<ShopArticleVo>> getShopArticleList(ShopArticleDto shopArticleDto, int pageNum, int pageSize) {
        if (null == shopArticleDto.getShopId()) {
            return ResponseJson.error("参数异常", null);
        }
        PageHelper.startPage(pageNum, pageSize);
        List<ShopArticleVo> articleList = articleMapper.getShopArticleList(shopArticleDto);
        PageInfo<ShopArticleVo> pageInfo = new PageInfo<>(articleList);
        return ResponseJson.success(pageInfo);
    }

    @Override
    public ResponseJson<Void> updateArticleStatus(ShopArticleDto shopArticleDto) {
        Integer articleId = shopArticleDto.getArticleId();
        Integer status = shopArticleDto.getStatus();
        if (null == articleId || null == status) {
            return ResponseJson.error("参数异常", null);
        }
        articleMapper.updateArticleStatus(articleId, status);
        // 更新文章索引
        commodityFeign.updateArticleIndex(articleId);
        return ResponseJson.success(null);
    }

    @Override
    public ResponseJson<List<ArticleTypeVo>> getArticleTypeList() {
        List<ArticleTypeVo> articleTypeList = articleMapper.getArticleTypeList();
        return ResponseJson.success(articleTypeList);
    }

    @Override
    public ResponseJson<Void> deleteArticle(Integer articleId) {
        articleMapper.deleteArticle(articleId);
        // 更新文章索引
        commodityFeign.updateArticleIndex(articleId);
        return ResponseJson.success(null);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public ResponseJson<Void> saveBaikeProduct(BaikeProductDto baikeProductDto) {
        if (null == baikeProductDto.getShopId()) {
            return ResponseJson.error("参数异常，供应商id不能为空", null);
        }
        if (StringUtils.isEmpty(baikeProductDto.getName())) {
            return ResponseJson.error("参数异常，百科名称不能为空", null);
        }
        // 新增商品标识
        boolean newProductFlag = null == baikeProductDto.getProductId() || 0 == baikeProductDto.getProductId();
        BaikeProductPo baikeProductPo = new BaikeProductPo();
        BeanUtils.copyProperties(baikeProductDto, baikeProductPo);
        // 保存供应商百科商品
        if (newProductFlag) {
            baikeProductPo.setPublishSource(2);
            baikeProductPo.setAuditStatus(1);
            baikeProductPo.setBasePv(0);
            baikeProductPo.setActualPv(0);
            baikeProductPo.setOnlineStatus(1);
            baikeProductMapper.insertBaikeProduct(baikeProductPo);
        } else {
            baikeProductPo.setAuditStatus(1);
            baikeProductPo.setOnlineStatus(1);
            baikeProductMapper.updateBaikeProduct(baikeProductPo);
        }
        Integer productId = baikeProductPo.getProductId();
        // 删除原先的图片/参数/问题数据
        if (!newProductFlag) {
            baikeProductMapper.deleteParamsByProductId(productId);
            baikeProductMapper.deleteImagesByProductId(productId);
            baikeProductMapper.deleteQuestionsByProductId(productId);
        }
        // 保存参数
        JSONArray paramArray = JSONArray.parseArray(baikeProductDto.getParamList());
        if (null != paramArray) {
            paramArray.forEach(paramObject->{
                Map<String,String> paramMap = (Map<String,String>) paramObject;
                String name = paramMap.get("name");
                String content = paramMap.get("content");
                if (StringUtils.isNotEmpty(name) && StringUtils.isNotEmpty(content)) {
                    baikeProductMapper.insertProductParam(name, content, productId);
                }
            });
        }
        // 保存认证图片
        List<String> authImageList = baikeProductDto.getAuthImageList();
        if (null != authImageList) {
            authImageList.forEach(authImage-> baikeProductMapper.insertProductImage(authImage, productId, 1));
        }
        // 保存展示图片
        List<String> displayImageList = baikeProductDto.getDisplayImageList();
        if (null != displayImageList) {
            displayImageList.forEach(diplayImage-> baikeProductMapper.insertProductImage(diplayImage, productId, 2));
        }
        // 保存问题
        JSONArray questionArray = JSONArray.parseArray(baikeProductDto.getQuestionList());
        if (null != questionArray) {
            questionArray.forEach(questionObject->{
                Map<String,String> questionMap = (Map<String,String>) questionObject;
                String question = questionMap.get("question");
                String answer = questionMap.get("answer");
                if (StringUtils.isNotEmpty(question) && StringUtils.isNotEmpty(answer)) {
                    baikeProductMapper.insertProductQuestion(question, answer, productId);
                }
            });
        }
        return ResponseJson.success(null);
    }

    @Override
    public ResponseJson<BaikeProductFormVo> getBaikeProductById(Integer productId) {
        if (null == productId) {
            return ResponseJson.error("参数异常", null);
        }
        // 查询商品信息
        BaikeProductFormVo baikeProduct = baikeProductMapper.getBaikeProductById(productId);
        if (null == baikeProduct) {
            return ResponseJson.error("百科不存在", null);
        }
        // 参数列表
        List<BaikeProductParamPo> paramList = baikeProductMapper.getParamList(productId);
        baikeProduct.setParamList(paramList);
        // 产品/仪器认证图片列表
        List<String> authImageList = baikeProductMapper.getImageList(productId, 1);
        baikeProduct.setAuthImageList(authImageList);
        // 效果展示图片列表
        List<String> displayImageList = baikeProductMapper.getImageList(productId, 2);
        baikeProduct.setDisplayImageList(displayImageList);
        // 问题列表
        List<BaikeProductQuestionPo> questionList = baikeProductMapper.getQuestionList(productId);
        baikeProduct.setQuestionList(questionList);
        return ResponseJson.success(baikeProduct);
    }


    @Override
    public ResponseJson<PageInfo<BaikeProductListVo>> getBaikeProductList(BaikeProductDto baikeProductDto, int pageNum, int pageSize) {
        if (null == baikeProductDto.getShopId() || null == baikeProductDto.getCommodityType()) {
            return ResponseJson.error("参数异常", null);
        }
        PageHelper.startPage(pageNum, pageSize);
        List<BaikeProductListVo> baikeProductList = baikeProductMapper.getBaikeProductList(baikeProductDto);
        PageInfo<BaikeProductListVo> pageInfo = new PageInfo<>(baikeProductList);
        return ResponseJson.success(pageInfo);
    }

    @Override
    public ResponseJson<Void> updateBaikeProductStatus(BaikeProductDto baikeProductDto) {
        Integer productId = baikeProductDto.getProductId();
        Integer status = baikeProductDto.getStatus();
        if (null == productId || null == status) {
            return ResponseJson.error("参数异常", null);
        }
        baikeProductMapper.updateBaikeProductStatus(productId, status);
        return ResponseJson.success(null);
    }

    @Override
    public ResponseJson<List<BaikeProductTypeVo>> getBaikeProductTypeList(Integer commodityType) {
        List<BaikeProductTypeVo> baikeProductTypeList = baikeProductMapper.getBaikeProductTypeList(commodityType);
        return ResponseJson.success(baikeProductTypeList);
    }

    @Override
    public ResponseJson<Void> deleteBaikeProduct(Integer productId) {
        baikeProductMapper.deleteBaikeProduct(productId);
        return ResponseJson.success(null);
    }

}
